驯龙高手 (豆瓣)
Description: 驯龙高手电影简介和剧情介绍,驯龙高手影评、图片、预告片、影讯、论坛、在线购票
Keywords: 驯龙高手,How to Train Your Dragon,驯龙高手影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.129豆瓣电影Top250

# 驯龙高手 How to Train Your Dragon (2010)

导演: 迪恩·德布洛斯 / 克里斯·桑德斯
编剧: 威廉姆·戴维斯 / 迪恩·德布洛斯 / 克里斯·桑德斯 / 葛蕾熙达·柯维尔
主演: 杰伊·巴鲁切尔 / 杰拉德·巴特勒 / 克雷格·费格森 / 亚美莉卡·费雷拉 / 乔纳·希尔 / 克里斯托夫·梅兹-普莱瑟 / T·J·米勒 / 克里斯汀·韦格 / 罗宾·阿特金·唐斯 / 菲利普·麦格雷德 / 基隆·埃利奥特 / 阿什利·詹森 / 大卫·田纳特
类型: 动画 / 奇幻 / 冒险
官方网站: www.dreamworksdragons.com/
制片国家/地区: 美国
语言: 英语
上映日期: 2010-05-14(中国大陆) / 2010-03-18(俄罗斯) / 2010-03-26(美国)
片长: 98分钟
又名: 驯龙记(港)
IMDb: tt0892769
豆瓣评分
引用
8.8
719770人评价
5星
48.5%
4星
41.4%
3星
9.6%
2星
0.4%
1星
0.1%
好于 97% 动画片
好于 97% 奇幻片
想看 看过
评价:
推荐

## 驯龙高手的剧情简介 · · · · · ·

维京岛国的少年小嗝嗝（杰伊•巴鲁切尔 Jay Baruchel 配音）是部落统领伟大的斯托里克（杰拉德·巴特勒 Gerard Butler 配音）的儿子，他非常想像自己的父亲一样亲手屠龙——这些飞龙是岛上维京人放牧羊群的主要天敌——但他每次出现在部落屠龙的战斗中都只给大家徒增烦恼。在一次对抗飞龙的战斗中，希卡普偷偷用射龙器击伤了一只最神秘的“夜之怒龙”，并背着族人放生、豢养，甚至驯服了这只龙，还给它起名“无牙”。希卡普的神秘行径引起了一同训练屠龙技巧的女孩阿斯特丽德（亚美莉卡·费雷拉 America Ferrera 配音）的怀疑。阿斯特丽德发现了希卡普的秘密，却同时被身骑“无牙”御风而飞的美妙体验所震撼。格雷决定在屠龙成人礼上向远征归来的斯托里克和族人讲明真相，说服大家放弃屠龙，却偏偏弄巧成拙，害得“无牙”被俘，一场更大的灾难就在眼前…… ©豆瓣

## 驯龙高手的演职员 · · · · · · ( 全部 23 )

- 迪恩·德布洛斯 导演
- 克里斯·桑德斯 导演
- 杰伊·巴鲁切尔 配 小嗝嗝 Hiccup
- 杰拉德·巴特勒 配 史图伊克 Stoick
- 克雷格·费格森 配 戈伯 Gobber
- 亚美莉卡·费雷拉 配 亚丝翠 Astrid

## 驯龙高手的视频和图片 · · · · · · ( 预告片10 | 添加视频评论 | 图片555 · 添加 )

## 驯龙高手的获奖情况 · · · · · · ( 全部 )

- 第83届奥斯卡金像奖
- 最佳动画长片(提名)
- 克里斯·桑德斯 / 迪恩·德布洛斯

- 第67届威尼斯电影节
- 3-D电影奖 年度最具创意立体电影
- 克里斯·桑德斯

- 第68届金球奖
- 电影类 最佳动画长片(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  大闹天宫

  幽灵公主

  哈尔的移动城堡

  怪兽电力公司

  风之谷

  神偷奶爸

  玩具总动员

  冰川时代

  驯龙高手2

我要写短评

## 驯龙高手的短评 · · · · · · ( 全部 117318 条 )

热门 / 最新 / 好友

### 573 有用 薇记和风韭菜饺 看过 2010-04-03 03:27:29

强过阿烦达太多太多了

### 1916 有用 THE M 看过 2010-03-28 23:33:23

哇哇哇好看 那龙的原型绝对是一猫

### 3401 有用 with 看过 2010-05-18 20:31:14

和谐的生活离不开摸头与被摸头

### 1298 有用 玻璃被子 看过 2010-03-29 07:03:20

我觉得今年其他的动画片可以不要演了

### 1721 有用 shell ❤ キリンさん。 看过 2010-03-29 00:22:19

妙蛙种子龙。。呜哇

> 更多短评 117318条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 驯龙高手的影评 · · · · · · ( 全部 954 条 )

热门 / 最新 / 好友
semifairy 2010-04-13 01:48:23

## 喷火闪电皆不重要，能卖萌才是王道

从电影院走出来，嘴角无法抑制地上扬。上一次一部电影让我这样发自内心地开怀大笑还是功夫熊猫。How to train your dragon, 名字好听，电影也好看，主要原因归纳如下： 1. 它满足了你我对宠物的终极幻想。宠物是只龙，这得多炫啊！此龙鼎鼎大名为“夜的震怒”，能上天入海，能... (展开)
1598 50 177回应 收起
TORO VAN DARKO 2010-04-03 09:18:13

## 因为有你，我才是完整的

电影结局的那一幕的确触动了我。Hiccup艰难的离开床，向门外走去，身边搀扶他的是从未曾离开的Toothless，导演刻意将Hiccup的下肢和Toothless的尾巴放在同一个镜头中。仅仅几秒钟的镜头里，讲述的是两个无论是心理，生活抑或只是躯体均残缺的个体，因为与对方相遇相识，... (展开)
1262 40 222回应 收起
天亮天黑 2010-05-15 15:00:44

## 我需要一部《驯龙猫高手》

去影院看了3D版的《驯龙高手》，灯光亮起的那一刹，就像是刚刚从华美的梦中骤然惊醒那般失落。 每个孩子在长大的过程中，总有那么一瞬间会渴望拥有这样一只宠物：它神通广大，法力无边，可以打败任何你讨厌的家伙，却只听你一个人的；它会在你需要它的时候及时出现；会在你郁... (展开)
303 36 80回应 收起
鸟甲 2010-05-26 07:24:03

## 利益至上——揭开《驯龙记》温情脉脉的面纱

警告：本文刻意对电影进行恶毒的过度解读，并有严重的装B倾向，不喜者慎入！ 大清道光28年，英夷首辅庙亨约（Henry John Temple）有云：“友敌无久远，利益永流传”。《驯龙记》（How to Train Your Dragon）一片貌似温馨地刻画了友情、亲情和爱情，但实际上却深刻揭示了利益... (展开)
311 102 145回应 收起
Huanhuan 2010-04-09 16:43:39

## 我们又一次站在了电影工业的拐点

影片开始之前播放的预告篇，无一例外的都是即将在3D影院上映的故事：分别是三维动画鼻祖 Toy Story 3 , 守护者的传奇， 怪物史来客终结篇。 然后梦工厂那个新月上钓鱼的小孩3D 影院版本出现了，这是我记忆当中唯一的一次，在影片厂标出来的时候就心潮澎湃的影院经历。 因为我... (展开)
108 27 22回应 收起
聂小无 2010-03-26 22:57:09

## “You Are My Son。”

这篇影评可能有剧透

Avatar之后几乎所有的3D电影都要跟它比较一番。Alice In Wonderland里我只记住了那只裂口的猫和Mia Wasikowska唇上那颗美人痣，出门的时候咬咬牙跟朋友说挺好的。画面感还是不错的，看Alice小姐那几条裙子多飘逸啊，Depp一脸油墨妆多销魂啊，安妮海瑟薇多毒舌啊，嘴巴都是纯黑... (展开)
67 11 37回应 收起
果果 2010-05-03 13:14:21

## 对维京人感冒的可以看一下

英语:Viking 瑞典语:Vikingarna 【简介】 中世纪是个荒蛮的时代，不单指人文的凋敝，新兴的国家各恃武力，争抢着罗马帝国昔日的版图。凯尔特人、法兰克人、汪达尔人、萨克逊人，纷纷建立起各自的国家，当然还有维京人。 维京人生活在1000多年前的北欧，今天的挪... (展开)
71 6 6回应 收起
Stella_仓鼠 2010-06-24 00:40:05

## 电影中出场龙类的档案

以下资料来自电影官网，本人手工翻译，附加评注 夜煞 作为最罕见和最聪明的龙类，夜煞以它黑色的外形、锐利的黄色眼睛、略小的体型、沉重的胸廓和短脖子【评论：脖子短么？我觉得没牙仔的脖子也不算短了，这大概是“短，是相对的”吧】著称。它们拥有所有龙类中最大的翼展比... (展开)
45 2 10回应 收起
邝言 2010-07-12 16:21:36

## How to Train Your Dragon:驯养，即是建立一种关联

这篇影评可能有剧透

两个印第安人，一个勇士和一个智者，看到男主人公在辽阔的草原上同一头野狼嬉戏，便给他取了一个诗意的名字：与狼共舞——这也就是那部史诗般的影片的名字。片中有这样一幕，在经过了无数次的犹疑和试探之后，那头狼终于伏下身体从男主人公的手中叼走了食物，“那一低头的温柔... (展开)
50 3 11回应 收起

> 更多影评 954篇

添加新讨论

## 讨论区 · · · · · ·

无牙仔嘿嘿嘿??? | 来自lgofoyu |  | 2022-11-22 13:18:02
本片中是否有性隐喻？ | 来自Arthur | 10 回应 | 2022-11-14 13:31:54
小嗝嗝 | 来自aaaaa | 1 回应 | 2022-11-02 16:54:20
可爱龙 | 来自言浠 |  | 2022-11-02 16:53:50
FY看第二遍 | 来自CL |  | 2022-10-30 10:45:48

> 去这部影片的讨论区（全部214条）

## 关于《驯龙高手》的问题 · · · · · · ( 全部8个 )

- 有人知道为什么Toothless尾巴上的翅膀会少了一半么？ 6人回答
- 关于龙的种类有什么书籍可以看的？最好包括插图？ 1人回答

> 全部8个问题

## 在哪儿看这部电影 · · · · · ·

- 优酷视频 VIP免费观看
- 爱奇艺视频 VIP免费观看
- 腾讯视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- {北美电影票房总排行} (荔枝超人)
- 【爱看动画】 (影志)
- 同时入选IMDB250和豆瓣电影250的电影 (东方快车)
- 第83届奥斯卡+第68届金球奖 获奖/候选影片 (影志)

## 谁在看这部电影 · · · · · ·

- whcwhcwhc
  3分钟前 看过
- 264726162
  7分钟前 看过
- Cloris雷菁
  7分钟前 看过

1258987人看过 / 141973人想看

订阅驯龙高手的评论:
feed: rss 2.0